# subsheets

> Utility to create subsheets in excel file.

## Usage

### Install
`
    pip install subsheets
`

and then
`
    subsheets <new_file_name>
`

the program will ask for the source directory where the files are present. The
new file will be created in the same directory.

## Contribute

### Clone the source
`
    https://github.com/CruiseDevice/subsheets
`

### Navigate inside the subsheets folder
`
    cd subsheets/
`

### Install the dependencies
`
    pip install -r requirements.txt
`

### Navigate inside the src/ folder
`
    cd src/
`

### Usage
`
    python subsheets.py <new-file_name>
`

#### Note: Make the changes in the different branch and send the PR.